@@ -1171,6 +1171,7 @@ GSList* gok_spy_append_node (GSList* nodes,
 		AccessibleHypertext *hypertext = Accessible_getHypertext (pAccessible);
 		AccessibleText *text = Accessible_getText (pAccessible);
 		gint i, nlinks = AccessibleHypertext_getNLinks (hypertext);
+		gok_log ("object contains hypertext.");
 		for (i = 0; i < nlinks; ++i) {
 			AccessibleHyperlink *link = AccessibleHypertext_getLink (hypertext, i);
 			Accessible *link_object = AccessibleHyperlink_getObject (link, 0);
@@ -1238,20 +1239,20 @@ GSList* gok_spy_append_node (GSList* nodes,
 		if (pName == NULL) {
 			Accessible *parent = Accessible_getParent (pAccessible);
 			/* if there are no siblings, we can use an ancestor's name */
+			gok_log("checking ancestor names.");
 			while (parent && Accessible_getChildCount (parent) == 1) 
 			{
+				char *tmp;
 				Accessible *tmp_parent = parent;
-				pName = Accessible_getName (tmp_parent); 
-				if (pName != NULL) 
+				tmp = Accessible_getName (tmp_parent); 
+				if (tmp != NULL) 
 				{
-				    char *tmp = NULL;
-				    if (strlen (pName) > 0) 
+				    if (strlen (tmp) > 0) 
 				    {
-					tmp = g_strdup (pName);
+					pName = g_strdup (tmp);
 					break;
 				    }
-				    SPI_freeString (pName);
-				    pName = tmp;
+				    SPI_freeString (tmp);
 				}
 				parent = Accessible_getParent (tmp_parent);
 				Accessible_unref (tmp_parent);
@@ -1264,7 +1265,7 @@ GSList* gok_spy_append_node (GSList* nodes,
 			s = Accessible_getDescription (pAccessible);
 			if (s != NULL) {
 				gint len = strlen (s);
-				if ( len != 0 )  {
+				if ( len > 0 )  {
 					if (len > 18) 
 					{
 						gchar *tmp = NULL;
@@ -1321,10 +1322,10 @@ GSList* gok_spy_append_node (GSList* nodes,
 					else {
 						len = 0;
 					}
-					if (len) {
+					if (len > 0) {
 						if (gs) {
 							tmp = gs;
-							gs = g_strconcat (gs, word, NULL);
+							gs = g_strconcat (tmp, word, NULL);
 							g_free (tmp);
 						}
 						else {
