@@ -230,7 +230,7 @@ static int gok_sig_handler(int sig)
 	switch (sig) {
 	case SIGSEGV:
 		segfaults++;
-		fprintf (stderr, "gok: Segmentation fault\n");
+		/* fprintf (stderr, "gok: Segmentation fault\n"); */
 		break;
 	case SIGTERM:
 		fprintf (stderr, "gok: exiting (terminated)\n");
@@ -241,7 +241,7 @@ static int gok_sig_handler(int sig)
 	}
 	
 	if (segfaults == 1)
-		gok_main_close();
+	    gok_main_close(); 
 
 	_exit(1);
 	return -1;  /* this line gets rid of compiler warning */ 
@@ -407,7 +407,6 @@ gok_main_open(gint argc, gchar *argv[])
 	if (gok_data_get_use_gtkplus_theme () == FALSE)
 	{
 		gok_main_read_rc ();
-		gok_main_stop_theme_change_notify ();
 		gok_log ("gok_main_read_rc has finished");
 	}
 
@@ -820,7 +819,7 @@ void gok_main_motion_listener (gint n_axes, int *motion_data, long mods, long ti
 		if (gok_data_get_drive_corepointer ()) {
 			XWarpPointer (display, None, 
 				      GDK_WINDOW_XWINDOW (root),
-				      0, 0, 0, 0, dx, dy);
+				      0, 0, 0, 0, motion_data[0], motion_data[1]);
 		}
 	}
 }
@@ -1434,37 +1433,6 @@ gok_main_read_rc ()
     }
 }
 
-/**
- * gok_main_stop_theme_change_notify:
- *
- * stop the theme change monitoring by removing 
- * the gtk-theme-name property from the GtkSetting object
- * and reset the application to the default gtk theme
- */
-
-gok_main_stop_theme_change_notify ()
-{
-  GdkDisplay *dpy = gdk_display_get_default ();
-  int i,j, num_scr = gdk_display_get_n_screens (dpy);
-
-  for (i=0; i < num_scr; i++)
-    {
-      GdkScreen *scr = gdk_display_get_screen (dpy, i);
-      GtkSettings *settings = gtk_settings_get_for_screen (scr);
-      GParamSpec* theme_name_spec = g_object_class_find_property (G_OBJECT_GET_CLASS (settings), "gtk-theme-name");
-      if (theme_name_spec)
-	{
-	  int ref_count;
-	  /* reset to default gtk theme */
-	  g_object_set (settings,"gtk-theme-name", "Default", NULL); 
-	  ref_count = theme_name_spec->ref_count;
-
-	  for (j = 0; j < ref_count; j++)
-	    g_param_spec_unref (theme_name_spec);
-	}
-    }
-}
-
 /**
 * gok_main_read_keyboards:
 *
@@ -1582,6 +1550,18 @@ GokKeyboard* gok_main_read_keyboards_from_dir (const char *directory)
 		pKeyboardPrevious = pKeyboard;
 	}
 
+	/* create the Alpha and Alpha-Freq keyboards */
+	pKeyboard = gok_keyboard_get_alpha ();
+	pKeyboard->pKeyboardNext = pKeyboardPrevious->pKeyboardNext;
+	pKeyboardPrevious->pKeyboardNext = pKeyboard;
+	pKeyboard->pKeyboardPrevious = pKeyboardPrevious;
+	pKeyboardPrevious = pKeyboard;
+	pKeyboard = gok_keyboard_get_alpha_by_frequency ();
+	pKeyboard->pKeyboardNext = pKeyboardPrevious->pKeyboardNext;
+	pKeyboardPrevious->pKeyboardNext = pKeyboard;
+	pKeyboard->pKeyboardPrevious = pKeyboardPrevious;
+	pKeyboardPrevious = pKeyboard;	
+
 	/* look at each file in the directory */
 	while ((pDirectoryEntry = readdir (pDirectoryKeyboards)) != NULL)
 	{
@@ -2275,7 +2255,7 @@ gok_main_check_sticky_keys (GtkWidget *widget)
 								 GTK_DIALOG_DESTROY_WITH_PARENT,
 								 GTK_MESSAGE_INFO,
 								 GTK_BUTTONS_OK,
-								 "GOK has enabled Sticky Keys, which it requires.\n");
+								 _("GOK has enabled Sticky Keys, which it requires.\n"));
 				
 				  /* Destroy the dialog when the user responds to it (e.g. clicks a button) */
 				  g_signal_connect_swapped (GTK_OBJECT (dialog), "response",
@@ -2296,7 +2276,7 @@ gok_main_check_sticky_keys (GtkWidget *widget)
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_ERROR,
 						 GTK_BUTTONS_CLOSE,
-						 "GOK cannot run because XKB display extension is missing.\n");		
+						 _("GOK cannot run because XKB display extension is missing.\n"));
 			g_signal_connect_swapped (GTK_OBJECT (dialog), "response",
 					  G_CALLBACK (gtk_widget_destroy),
 					  GTK_OBJECT (dialog));
